sample_data creates a generated data set to test the included methods.
Source:R/sample_data.R
sample_data.RdThe data.frame contains a collection of columns with sample data
Examples
# create the data set
dta <- sample_data(n = 100)
udta <- r_data_types(dta)
lmap <- label_map(dta)